==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/BehaviorPreferences/ts/BehaviorPreferences_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>BehaviorPreferences</name>
    <message>
        <location filename="../BehaviorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Ver Gráficos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Behavior</source>
        <translation>Comportamento</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+48"/>
        <source>Double-Click</source>
        <translation>Clique Duplo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Double-click to edit text</source>
        <translation>Clique duplo para editar o texto</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click to edit hatch</source>
        <translation>Clique duplo para editar o hachura</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click on block reference opens block</source>
        <translation>Clique duplo na referência do bloco para abrir o bloco</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Right double-click to reset</source>
        <translation>Clique duplo de direita para resetar</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Blocks</source>
        <translation>Blocos</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Select block references together with attributes</source>
        <translation>Selecione referências de blocos juntamente com seus atributos</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Hide attributes when block references are hidden</source>
        <translation>Ocultar atributos quando as referências de blocos estão escondidos</translation>
    </message>
    <message>
        <location line="-85"/>
        <source>Right-Click</source>
        <translation>Clique do Botão Direito</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Right-click to deselect entities</source>
        <translation>Clique direito para desmarcar entidades </translation>
    </message>
    <message>
        <source>Right-click on entity shows context menu</source>
        <translation type="vanished">Clique direito en un entidade mostra menu de contexto</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Double-click to select contour</source>
        <translation>Clique duplo para selecionar contorno</translation>
    </message>
    <message>
        <source>Block Selection</source>
        <translation type="vanished">Bloco seleção</translation>
    </message>
    <message>
        <source>Select block reference with attribute</source>
        <translation type="obsolete">Selecione referência de bloco com o atributo</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Cursor Range</source>
        <translation>Limites do Cursor</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Cursor range for snap:</source>
        <translation>Limites do cursor para salto:</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>Cursor range for picking entities:</source>
        <translation>Limites do cursor para escolher entidades:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/BehaviorPreferences/ts/BehaviorPreferences_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>BehaviorPreferences</name>
    <message>
        <location filename="../BehaviorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Ver Gráficos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Behavior</source>
        <translation>Comportamento</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+48"/>
        <source>Double-Click</source>
        <translation>Clique Duplo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Double-click to edit text</source>
        <translation>Clique duplo para editar o texto</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click to edit hatch</source>
        <translation>Clique duplo para editar o hachura</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click on block reference opens block</source>
        <translation>Clique duplo na referência do bloco para abrir o bloco</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Right double-click to reset</source>
        <translation>Clique duplo de direita para resetar</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Blocks</source>
        <translation>Blocos</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Select block references together with attributes</source>
        <translation>Selecione referências de blocos juntamente com seus atributos</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Hide attributes when block references are hidden</source>
        <translation>Ocultar atributos quando as referências de blocos estão escondidos</translation>
    </message>
    <message>
        <location line="+126"/>
        <source>Highlight entity within range</source>
        <translation>Realçar entidade dentro do intervalo</translation>
    </message>
    <message>
        <source>Keyboard Operations</source>
        <translation type="vanished">Operações de teclado</translation>
    </message>
    <message>
        <source>Angle step for rotating:</source>
        <translation type="vanished">Passo angular para rotação:</translation>
    </message>
    <message>
        <location line="-211"/>
        <source>Right-Click</source>
        <translation>Clique do Botão Direito</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Right-click to deselect entities</source>
        <translation>Clique direito para desmarcar entidades </translation>
    </message>
    <message>
        <source>Right-click on entity shows context menu</source>
        <translation type="vanished">Clique direito en un entidade mostra menu de contexto</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Double-click to select contour</source>
        <translation>Clique duplo para selecionar contorno</translation>
    </message>
    <message>
        <source>Block Selection</source>
        <translation type="vanished">Bloco seleção</translation>
    </message>
    <message>
        <source>Select block reference with attribute</source>
        <translation type="obsolete">Selecione referência de bloco com o atributo</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Cursor Range</source>
        <translation>Limites do Cursor</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>Cursor range for snap:</source>
        <translation>Limites do cursor para salto:</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Cursor range for picking entities:</source>
        <translation>Limites do cursor para escolher entidades:</translation>
    </message>
</context>
</TS>
